.. _sec-bibliography:

Bibliography
============

.. [AC2004] Abramsky S, Coecke B. `A Categorical Semantics for Quantum Protocols <https://arxiv.org/pdf/quant-ph/0402130.pdf>`_, LiCS 2004

.. [SC2021] Clark S. `Something Old, Something New: Grammar-based CCG Parsing with Transformer Models <https://arxiv.org/pdf/2109.10044.pdf>`_, `arXiv:2109.10044`, 2021

.. [CSC2010] Coecke B, Sadrzadeh M, Clark S. `Mathematical Foundations for a Compositional Distributional Model of Meaning <https://arxiv.org/pdf/1003.4394.pdf>`_, `Lambek Festschirft`, special issue of `Linguistic Analysis`, 2010

.. [CW2021] Coecke B, Wang V. `Grammar Equations <https://arxiv.org/pdf/2106.07485.pdf>`_, `SemSpace 2021`

.. [FTC2020] de Felice G, Toumi A, Coecke B. `DisCoPy: Monoidal Categories in Python <https://arxiv.org/pdf/2005.02975.pdf>`_, `ACT 2020`

.. [GL2012] Gao F, Lixing H. `Implementing the Nelder-Mead Simplex Algorithm with Adaptive Parameters <https://link.springer.com/article/10.1007/s10589-010-9329-3>`_, `Computational Optimization and Applications`,` 51. 259-277.10.1007/s10589-010-9329-3, 2012

.. [Hea2019] Havlíček V, Córcoles A, Temme K, Harrow A, Kandala A, Chow J, Gambetta J. `Supervised Learning with Quantum-Enhanced Feature Spaces <https://www.nature.com/articles/s41586-019-0980-2>`_. `Nature`, 567, 2019

.. [HS2007] Hockenmaier J, Steedman M. `CCGbank: A Corpus of CCG Derivations and Dependency Structures Extracted from the Penn Treebank <https://aclanthology.org/J07-3004.pdf>`_, `Computational Linguistics, Volume 33, Number 3`, September 2007

.. [HV2013] Heunen C, Vicary J. `Introduction to Categorical Quantum Mechanics <http://www.cs.ox.ac.uk/people/jamie.vicary/IntroductionToCategoricalQuantumMechanics.pdf>`_, `Course Notes`, Oxford University, 2013

.. [Kar2016] Kartsaklis D. `Coordination in Categorical Compositional Distributional Semantics <https://arxiv.org/pdf/1606.01515.pdf>`_, `SemSpace 2016`

.. [Kea2014] Kartsaklis D, Sadrzadeh M, Pulman S, Coecke B. `Reasoning about Meaning in Natural Language with Compact Closed Categories and Frobenius Algebras <https://arxiv.org/pdf/1401.5980.pdf>`_, `Logic and Algebraic Structures in Quantum Computing and Information`, 2014

.. [Kea2021] Kartsaklis D, Fan I, Yeung R, Pearson A, Lorenz R, Toumi A, de Felice G, Meichanetzidis K, Clark S, Coecke B. `lambeq: An Efficient High-Level Python Library for Quantum NLP <https://arxiv.org/pdf/2110.04236.pdf>`_, `arXiv:2110.04236`, 2021

.. [Lam1999] Lambek J. Type Grammar Revisited, `Logical Aspects of Computational Linguistics`, 1999

.. [Lea2021] Lorenz R, Pearson A, Meichanetzidis K, Kartsaklis D, Coecke B. `QNLP in Practice: Running Compositional Models of Meaning on a Quantum Computer <https://arxiv.org/pdf/2102.12846.pdf>`_ `arXiv:2102.12846`, 2021

.. [NM1965] Nelder J, Mead R. `A Simplex Method for Function Minimization <https://people.duke.edu/~hpgavin/cee201/Nelder+Mead-ComputerJournal-1965.pdf>`_, `The Computer Journal` 7: 308-13, 1965

.. [Mea2020] Meichanetzidis K, Toumi A, de Felice G, Coecke B. `Grammar-Aware Question-Answering on Quantum Computers <https://arxiv.org/pdf/2012.03756.pdf>`_, `arXiv:2012.03756`, 2020

.. [Oea2021] Ostaszewski M, Grant E, Benedetti M.  `Structure Optimization for Parameterized Quantum Circuits <https://quantum-journal.org/papers/q-2021-01-28-391/pdf/>`_, `Quantum`, 2021

.. [Rea2016] Rimell L, Maillard J, Polajnar T, Clark S. `RELPRON: A Relative Clause Evaluation Data Set for Compositional Distributional Semantics <https://direct.mit.edu/coli/article/42/4/661/1555/RELPRON-A-Relative-Clause-Evaluation-Data-Set-for>`_, `Computational Linguistics`, 2016

.. [SCC2014a] Sadrzadeh M, Clark S, Coecke B. `The Frobenius Anatomy of Word Meanings I: Subject and Object Relative Pronouns <https://arxiv.org/pdf/1404.5278.pdf>`_, `Journal of Logic and Computation`, 2014

.. [SCC2014b] Sadrzadeh M, Clark S, Coecke B. `The Frobenius Anatomy of Word Meanings II: Possessive Relative Pronouns <https://arxiv.org/pdf/1406.4690.pdf>`_, `Journal of Logic and Computation`, 2014

.. [SJA2019] Sim S, Johnson P, Aspuru-Guzik A. `Expressibility and Entangling Capability of Parameterized Quantum Circuits for Hybrid Quantum-Classical Algorithms <https://arxiv.org/pdf/1905.10876.pdf>`_, `arXiv:1905.10876`, 2019

.. [Spa1998] Spall J C. `Implementation of the simultaneous perturbation algorithm for stochastic optimization <https://ieeexplore.ieee.org/document/705889>`_, `IEEE Transactions on Aerospace and Electronic Systems`, 1998

.. [Ste2000] Steedman M. The Syntactic Process, MIT Press, 2000

.. [YK2021] Yeung R, Kartsaklis D. `A CCG-Based Version of the DisCoCat Framework <https://aclanthology.org/2021.semspace-1.3.pdf>`_, `SemSpace 2021`

.. [YNM2017] Yoshikawa M, Noji H, Matsumoto Y. `A* CCG Parsing with a Supertag and Dependency Factored Model <https://arxiv.org/pdf/1704.06936.pdf>`_, `ACL 2017`
